@@ -9,9 +9,9 @@ describe "id fact" do
     kernel.each do |k|
         describe "with kernel reported as #{k}" do
             it "should return the current user" do
-                Facter::Util::Resolution.stubs(:exec).with('uname -s').returns(k)
-                Facter::Util::Resolution.stubs(:exec).with('lsb_release -a 2>/dev/null').returns('foo')
-                Facter::Util::Resolution.expects(:exec).once.with('whoami', '/bin/sh').returns 'bar'
+                Facter.fact(:kernel).stubs(:value).returns(k)
+                Facter::Util::Config.stubs(:is_windows?).returns(k == 'windows')
+                Facter::Util::Resolution.expects(:exec).once.with('whoami').returns 'bar'
 
                 Facter.fact(:id).value.should == 'bar'
             end
@@ -19,9 +19,10 @@ describe "id fact" do
     end
 
     it "should return the current user on Solaris" do
+       Facter::Util::Config.stubs(:is_windows?).returns(false)
        Facter::Util::Resolution.stubs(:exec).with('uname -s').returns('SunOS')
-       Facter::Util::Resolution.expects(:exec).once.with('/usr/xpg4/bin/id -un', '/bin/sh').returns 'bar'
+       Facter::Util::Resolution.expects(:exec).once.with('/usr/xpg4/bin/id -un').returns 'bar'
 
        Facter.fact(:id).value.should == 'bar'
-    end 
+    end
 end
