@@ -5,8 +5,13 @@ require File.expand_path(File.dirname(__FILE__) + '/../../spec_helper')
 require 'facter/util/ip'
 
 describe Facter::Util::IP do
-    [:freebsd, :linux, :netbsd, :openbsd, :sunos, :darwin, :"hp-ux", :"gnu/kfreebsd"].each do |platform|
+    before :each do
+        Facter::Util::Config.stubs(:is_windows?).returns(false)
+    end
+
+    [:freebsd, :linux, :netbsd, :openbsd, :sunos, :darwin, :"hp-ux", :"gnu/kfreebsd", :windows].each do |platform|
         it "should be supported on #{platform}" do
+            Facter::Util::Config.stubs(:is_windows?).returns(platform == :windows)
             Facter::Util::IP.supported_platforms.should be_include(platform)
         end
     end
@@ -22,39 +27,47 @@ describe Facter::Util::IP do
 
     it "should return a list with a single interface and the loopback interface on Linux with a single interface" do
         sample_output_file = File.dirname(__FILE__) + '/../data/linux_ifconfig_all_with_single_interface'
-        linux_ifconfig = File.new(sample_output_file).read()
+        linux_ifconfig = File.read(sample_output_file)
         Facter::Util::IP.stubs(:get_all_interface_output).returns(linux_ifconfig)
         Facter::Util::IP.get_interfaces().should == ["eth0", "lo"]
     end
 
     it "should return a list two interfaces on Darwin with two interfaces" do
         sample_output_file = File.dirname(__FILE__) + '/../data/darwin_ifconfig_all_with_multiple_interfaces'
-        darwin_ifconfig = File.new(sample_output_file).read()
+        darwin_ifconfig = File.read(sample_output_file)
         Facter::Util::IP.stubs(:get_all_interface_output).returns(darwin_ifconfig)
         Facter::Util::IP.get_interfaces().should == ["lo0", "en0"]
     end
 
     it "should return a list two interfaces on Solaris with two interfaces multiply reporting" do
         sample_output_file = File.dirname(__FILE__) + '/../data/solaris_ifconfig_all_with_multiple_interfaces'
-        solaris_ifconfig = File.new(sample_output_file).read()
+        solaris_ifconfig = File.read(sample_output_file)
         Facter::Util::IP.stubs(:get_all_interface_output).returns(solaris_ifconfig)
         Facter::Util::IP.get_interfaces().should == ["lo0", "e1000g0"]
     end
 
     it "should return a list three interfaces on HP-UX with three interfaces multiply reporting" do
         sample_output_file = File.dirname(__FILE__) + '/../data/hpux_netstat_all_interfaces'
-        hpux_netstat = File.new(sample_output_file).read()
+        hpux_netstat = File.read(sample_output_file)
         Facter::Util::IP.stubs(:get_all_interface_output).returns(hpux_netstat)
         Facter::Util::IP.get_interfaces().should == ["lan1", "lan0", "lo0"]
     end
 
     it "should return a list of six interfaces on a GNU/kFreeBSD with six interfaces" do
         sample_output_file = File.dirname(__FILE__) + '/../data/debian_kfreebsd_ifconfig'
-        kfreebsd_ifconfig = File.new(sample_output_file).read()
+        kfreebsd_ifconfig = File.read(sample_output_file)
         Facter::Util::IP.stubs(:get_all_interface_output).returns(kfreebsd_ifconfig)
         Facter::Util::IP.get_interfaces().should == ["em0", "em1", "bge0", "bge1", "lo0", "vlan0"]
     end
 
+    it "should return a list of only connected interfaces on Windows" do
+        Facter.fact(:kernel).stubs(:value).returns("windows")
+        sample_output_file = File.dirname(__FILE__) + '/../data/windows_netsh_all_interfaces'
+        windows_netsh = File.read(sample_output_file)
+        Facter::Util::IP.stubs(:get_all_interface_output).returns(windows_netsh)
+        Facter::Util::IP.get_interfaces().should == ["Loopback Pseudo-Interface 1", "Local Area Connection", "Teredo Tunneling Pseudo-Interface"]
+    end
+
     it "should return a value for a specific interface" do
         Facter::Util::IP.should respond_to(:get_interface_value)
     end
@@ -66,7 +79,7 @@ describe Facter::Util::IP do
 
     it "should return ipaddress information for Solaris" do
         sample_output_file = File.dirname(__FILE__) + "/../data/solaris_ifconfig_single_interface"
-        solaris_ifconfig_interface = File.new(sample_output_file).read()
+        solaris_ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_single_interface_output).with("e1000g0").returns(solaris_ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("SunOS")
@@ -76,7 +89,7 @@ describe Facter::Util::IP do
 
     it "should return netmask information for Solaris" do
         sample_output_file = File.dirname(__FILE__) + "/../data/solaris_ifconfig_single_interface"
-        solaris_ifconfig_interface = File.new(sample_output_file).read()
+        solaris_ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_single_interface_output).with("e1000g0").returns(solaris_ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("SunOS")
@@ -86,7 +99,7 @@ describe Facter::Util::IP do
 
     it "should return calculated network information for Solaris" do
         sample_output_file = File.dirname(__FILE__) + "/../data/solaris_ifconfig_single_interface"
-        solaris_ifconfig_interface = File.new(sample_output_file).read()
+        solaris_ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.stubs(:get_single_interface_output).with("e1000g0").returns(solaris_ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("SunOS")
@@ -96,7 +109,7 @@ describe Facter::Util::IP do
 
     it "should return ipaddress information for HP-UX" do
         sample_output_file = File.dirname(__FILE__) + "/../data/hpux_ifconfig_single_interface"
-        hpux_ifconfig_interface = File.new(sample_output_file).read()
+        hpux_ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_single_interface_output).with("lan0").returns(hpux_ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("HP-UX")
@@ -106,7 +119,7 @@ describe Facter::Util::IP do
 
     it "should return macaddress information for HP-UX" do
         sample_output_file = File.dirname(__FILE__) + "/../data/hpux_ifconfig_single_interface"
-        hpux_ifconfig_interface = File.new(sample_output_file).read()
+        hpux_ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_single_interface_output).with("lan0").returns(hpux_ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("HP-UX")
@@ -116,7 +129,7 @@ describe Facter::Util::IP do
 
     it "should return macaddress with leading zeros stripped off for GNU/kFreeBSD" do
         sample_output_file = File.dirname(__FILE__) + "/../data/debian_kfreebsd_ifconfig"
-        kfreebsd_ifconfig = File.new(sample_output_file).read()
+        kfreebsd_ifconfig = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_single_interface_output).with("em0").returns(kfreebsd_ifconfig)
         Facter.stubs(:value).with(:kernel).returns("GNU/kFreeBSD")
@@ -126,7 +139,7 @@ describe Facter::Util::IP do
 
     it "should return netmask information for HP-UX" do
         sample_output_file = File.dirname(__FILE__) + "/../data/hpux_ifconfig_single_interface"
-        hpux_ifconfig_interface = File.new(sample_output_file).read()
+        hpux_ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_single_interface_output).with("lan0").returns(hpux_ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("HP-UX")
@@ -136,7 +149,7 @@ describe Facter::Util::IP do
 
     it "should return calculated network information for HP-UX" do
         sample_output_file = File.dirname(__FILE__) + "/../data/hpux_ifconfig_single_interface"
-        hpux_ifconfig_interface = File.new(sample_output_file).read()
+        hpux_ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.stubs(:get_single_interface_output).with("lan0").returns(hpux_ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("HP-UX")
@@ -146,7 +159,7 @@ describe Facter::Util::IP do
 
     it "should return interface information for FreeBSD supported via an alias" do
         sample_output_file = File.dirname(__FILE__) + "/../data/6.0-STABLE_FreeBSD_ifconfig"
-        ifconfig_interface = File.new(sample_output_file).read()
+        ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_single_interface_output).with("fxp0").returns(ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("FreeBSD")
@@ -156,7 +169,7 @@ describe Facter::Util::IP do
 
     it "should return macaddress information for OS X" do
         sample_output_file = File.dirname(__FILE__) + "/../data/Mac_OS_X_10.5.5_ifconfig"
-        ifconfig_interface = File.new(sample_output_file).read()
+        ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_single_interface_output).with("en1").returns(ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("Darwin")
@@ -166,7 +179,7 @@ describe Facter::Util::IP do
 
     it "should return all interfaces correctly on OS X" do
         sample_output_file = File.dirname(__FILE__) + "/../data/Mac_OS_X_10.5.5_ifconfig"
-        ifconfig_interface = File.new(sample_output_file).read()
+        ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_all_interface_output).returns(ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("Darwin")
@@ -176,7 +189,7 @@ describe Facter::Util::IP do
 
     it "should return a human readable netmask on Solaris" do
         sample_output_file = File.dirname(__FILE__) + "/../data/solaris_ifconfig_single_interface"
-        solaris_ifconfig_interface = File.new(sample_output_file).read()
+        solaris_ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_single_interface_output).with("e1000g0").returns(solaris_ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("SunOS")
@@ -186,7 +199,7 @@ describe Facter::Util::IP do
 
     it "should return a human readable netmask on HP-UX" do
         sample_output_file = File.dirname(__FILE__) + "/../data/hpux_ifconfig_single_interface"
-        hpux_ifconfig_interface = File.new(sample_output_file).read()
+        hpux_ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_single_interface_output).with("lan0").returns(hpux_ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("HP-UX")
@@ -197,7 +210,7 @@ describe Facter::Util::IP do
     it "should return a human readable netmask on Darwin" do
         sample_output_file = File.dirname(__FILE__) + "/../data/darwin_ifconfig_single_interface"
 
-        darwin_ifconfig_interface = File.new(sample_output_file).read()
+        darwin_ifconfig_interface = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_single_interface_output).with("en1").returns(darwin_ifconfig_interface)
         Facter.stubs(:value).with(:kernel).returns("Darwin")
@@ -208,7 +221,7 @@ describe Facter::Util::IP do
     it "should return a human readable netmask on GNU/kFreeBSD" do
         sample_output_file = File.dirname(__FILE__) + "/../data/debian_kfreebsd_ifconfig"
 
-        kfreebsd_ifconfig = File.new(sample_output_file).read()
+        kfreebsd_ifconfig = File.read(sample_output_file)
 
         Facter::Util::IP.expects(:get_single_interface_output).with("em1").returns(kfreebsd_ifconfig)
         Facter.stubs(:value).with(:kernel).returns("GNU/kFreeBSD")
@@ -228,10 +241,59 @@ describe Facter::Util::IP do
         end
     end
 
+    [:windows].each do |platform|
+        it "should not require conversion from hex on #{platform}" do
+            Facter::Util::IP.convert_from_hex?(platform).should be_false
+        end
+    end
+
     it "should return an arp address on Linux" do
         Facter.stubs(:value).with(:kernel).returns("Linux")
 
         Facter::Util::IP.expects(:get_arp_value).with("eth0").returns("00:00:0c:9f:f0:04")
         Facter::Util::IP.get_arp_value("eth0").should == "00:00:0c:9f:f0:04"
     end
+
+    describe "on Windows" do
+        before :each do
+            Facter.stubs(:value).with(:kernel).returns("windows")
+        end
+
+        it "should return ipaddress information" do
+            sample_output_file = File.dirname(__FILE__) + "/../data/windows_netsh_single_interface"
+            windows_netsh = File.read(sample_output_file)
+
+            Facter::Util::IP.expects(:get_output_for_interface_and_label).with("Local Area Connection", "ipaddress").returns(windows_netsh)
+
+            Facter::Util::IP.get_interface_value("Local Area Connection", "ipaddress").should == "172.16.138.216"
+        end
+
+        it "should return a human readable netmask" do
+            sample_output_file = File.dirname(__FILE__) + "/../data/windows_netsh_single_interface"
+            windows_netsh = File.read(sample_output_file)
+
+            Facter::Util::IP.expects(:get_output_for_interface_and_label).with("Local Area Connection", "netmask").returns(windows_netsh)
+
+            Facter::Util::IP.get_interface_value("Local Area Connection", "netmask").should == "255.255.255.0"
+        end
+
+        it "should return network information" do
+            sample_output_file = File.dirname(__FILE__) + "/../data/windows_netsh_single_interface"
+            windows_netsh = File.read(sample_output_file)
+
+            Facter::Util::IP.stubs(:get_output_for_interface_and_label).with("Local Area Connection", "ipaddress").returns(windows_netsh)
+            Facter::Util::IP.stubs(:get_output_for_interface_and_label).with("Local Area Connection", "netmask").returns(windows_netsh)
+
+            Facter::Util::IP.get_network_value("Local Area Connection").should == "172.16.138.0"
+        end
+
+        it "should return ipaddress6 information" do
+            sample_output_file = File.dirname(__FILE__) + "/../data/windows_netsh_single_interface6"
+            windows_netsh = File.read(sample_output_file)
+
+            Facter::Util::IP.expects(:get_output_for_interface_and_label).with("Teredo Tunneling Pseudo-Interface", "ipaddress6").returns(windows_netsh)
+
+            Facter::Util::IP.get_interface_value("Teredo Tunneling Pseudo-Interface", "ipaddress6").should == "2001:0:4137:9e76:2087:77a:53ef:7527"
+        end
+    end
 end
